@@ -1,14 +1,14 @@
-import numpy as np
 import dolfin
+import numpy as np
 
 try:
     from dolfin_adjoint import (
-        Function,
-        interpolate,
         Constant,
-        project,
-        assemble,
+        Function,
         FunctionAssigner,
+        assemble,
+        interpolate,
+        project,
     )
 except ImportError:
     from dolfin import (
@@ -20,11 +20,10 @@ except ImportError:
         FunctionAssigner,
     )
 
+from . import numpy_mpi, utils
+from .utils import DOLFIN_VERSION_MAJOR, getLogger, mpi_comm_world
 
-from . import utils
-from . import numpy_mpi
-
-from .utils import logger, mpi_comm_world, DOLFIN_VERSION_MAJOR
+logger = getLogger(__name__)
 
 
 def map_vector_field(f0, new_mesh, u=None, name="fiber", normalize=True):
@@ -34,21 +33,21 @@ def map_vector_field(f0, new_mesh, u=None, name="fiber", normalize=True):
     displacement (u). In that case we will just a Piola transform to
     map the vector field.
     """
-
+    representation = dolfin.parameters["form_compiler"]["representation"]
     if DOLFIN_VERSION_MAJOR > 2016:
         dolfin.parameters["form_compiler"]["representation"] = "quadrature"
 
     dolfin.parameters["form_compiler"]["quadrature_degree"] = 4
 
     ufl_elem = f0.function_space().ufl_element()
-    f0_new = dolfin.Function(dolfin.FunctionSpace(new_mesh, ufl_elem))
+    f0_new = Function(dolfin.FunctionSpace(new_mesh, ufl_elem))
 
     if u is not None:
 
         f0_mesh = f0.function_space().mesh()
         u_elm = u.function_space().ufl_element()
         V = dolfin.FunctionSpace(f0_mesh, u_elm)
-        u0 = dolfin.Function(V)
+        u0 = Function(V)
         # arr = numpy_mpi.gather_vector(u.vector())
         # numpy_mpi.assign_to_vector(u0.vector(), arr)
         u0.vector()[:] = u.vector()
@@ -56,7 +55,7 @@ def map_vector_field(f0, new_mesh, u=None, name="fiber", normalize=True):
 
         F = DeformationGradient(u0)
 
-        f0_updated = dolfin.project(F * f0, f0.function_space())
+        f0_updated = project(F * f0, f0.function_space())
 
         if normalize:
             f0_updated = normalize_vector_field(f0_updated)
@@ -71,7 +70,7 @@ def map_vector_field(f0, new_mesh, u=None, name="fiber", normalize=True):
         f0_new.vector()[:] = f0.vector()
 
     if DOLFIN_VERSION_MAJOR > 2016:
-        dolfin.parameters["form_compiler"]["representation"] = "uflacs"
+        dolfin.parameters["form_compiler"]["representation"] = representation
 
     return f0_new
 
@@ -88,8 +87,7 @@ def update_function(mesh, f):
 
 
 def normalize_vector_field(u):
-    """Given a vector field, return a vector field with an L2 norm equal to 1.0
-    """
+    """Given a vector field, return a vector field with an L2 norm equal to 1.0"""
     dim = len(u)
     S = u.function_space().sub(0).collapse()
 
@@ -102,23 +100,22 @@ def normalize_vector_field(u):
 
     assigners = [FunctionAssigner(u.function_space().sub(i), S) for i in range(dim)]
     for i, comp, assigner in zip(range(dim), components, assigners):
-        assigner.assign(u.sub(i), comp)
+        assigner.assign(u.split()[i], comp)
 
     return u
 
 
 def vectorfield_to_components(u, S, dim):
-    components = [dolfin.Function(S) for i in range(dim)]
+    components = [Function(S) for i in range(dim)]
     assigners = [FunctionAssigner(S, u.function_space().sub(i)) for i in range(dim)]
     for i, comp, assigner in zip(range(dim), components, assigners):
-        assigner.assign(comp, u.sub(i))
+        assigner.assign(comp, u.split()[i])
 
     return components
 
 
 def get_pressure(problem):
-    """Returns p_lv (and p_rv if BiV mesh)
-    """
+    """Returns p_lv (and p_rv if BiV mesh)"""
 
     plv = [p.traction for p in problem.bcs.neumann if p.name == "lv"]
     prv = [p.traction for p in problem.bcs.neumann if p.name == "rv"]
@@ -150,7 +147,7 @@ def read_hdf5(h5name, func, h5group="", comm=mpi_comm_world()):
             (
                 "Something went wrong when reading file "
                 "{h5name} into function {func} from group "
-                "{h5group)"
+                "{h5group}"
             ).format(h5name=h5name, func=func, h5group=h5group)
         )
         raise ex
@@ -309,7 +306,7 @@ def heaviside(x):
     return dolfin.conditional(dolfin.ge(x, 0.0), 1.0, 0.0)
 
 
-def list_sum(l):
+def list_sum(lst):
     """
     Return the sum of a list, when the convetiional
     method (like `sum`) it not working.
@@ -321,11 +318,11 @@ def list_sum(l):
 
     """
 
-    if not isinstance(l, list):
-        return l
+    if not isinstance(lst, list):
+        return lst
 
-    out = l[0]
-    for item in l[1:]:
+    out = lst[0]
+    for item in lst[1:]:
         out += item
     return out
 
@@ -522,7 +519,7 @@ class BaseExpression(dolfin.Expression):
             value[0] = 0
 
 
-class MixedParameter(dolfin.Function):
+class MixedParameter(Function):
     def __init__(self, fun, n, name="material_parameters"):
         """
         Initialize Mixed parameter.
@@ -577,12 +574,12 @@ class MixedParameter(dolfin.Function):
         :param int i: The subspace number
 
         """
-        f_ = dolfin.Function(self.basespace)
+        f_ = Function(self.basespace)
         f_.assign(f)
         self.function_assigner[i].assign(self.split()[i], f_)
 
 
-class RegionalParameter(dolfin.Function):
+class RegionalParameter(Function):
     """A regional paramerter defined in terms of a dolfin.MeshFunction
 
     Suppose you have a MeshFunction defined different regions in your mesh,
@@ -604,7 +601,7 @@ class RegionalParameter(dolfin.Function):
 
         V = dolfin.VectorFunctionSpace(mesh, "R", 0, dim=self._nvalues)
 
-        dolfin.Function.__init__(self, V)
+        Function.__init__(self, V)
         self._meshfunction = meshfunction
 
         # Functionspace for the indicator functions
@@ -626,8 +623,8 @@ class RegionalParameter(dolfin.Function):
 
         :returns: A function with parameter values at each segment
                   specified by the meshfunction
-        :rtype:  :py:class`dolfin.Function             
-             
+        :rtype:  :py:class`dolfin.Function
+
         """
         return self._sum()
 
@@ -642,7 +639,7 @@ class RegionalParameter(dolfin.Function):
     def _make_indicator_function(self, marker):
 
         dofs = self._meshfunction.where_equal(marker)
-        f = dolfin.Function(self._proj_space)
+        f = Function(self._proj_space)
         f.vector()[dofs] = 1.0
         return f
 
