@@ -1,12 +1,13 @@
 import os
-import numpy as np
-import h5py
+
 import dolfin
+import h5py
+import numpy as np
 
 try:
-    from dolfin_adjoint import Constant, Function
+    from dolfin_adjoint import Function, FunctionAssigner, interpolate
 except ImportError:
-    from dolfin import Constant, Function
+    from dolfin import Function, FunctionAssigner, interpolate
 
 # For newer versions of dolfin_adjoint
 try:
@@ -14,13 +15,10 @@ try:
 except ImportError:
     from dolfin import Mesh
 
-from . import numpy_mpi
 from . import io_utils
-from . import parameters
-from .utils import make_logger, mpi_comm_world, DOLFIN_VERSION_MAJOR
+from .utils import DOLFIN_VERSION_MAJOR, getLogger, mpi_comm_world
 
-
-logger = make_logger(__name__, parameters["log_level"])
+logger = getLogger(__name__)
 
 
 def move(mesh, u, factor=1.0):
@@ -30,14 +28,14 @@ def move(mesh, u, factor=1.0):
     W = dolfin.VectorFunctionSpace(u.function_space().mesh(), "CG", 1)
 
     # Use interpolation for now. It is the only thing that makes sense
-    u_int = dolfin.interpolate(u, W)
+    u_int = interpolate(u, W)
 
-    u0 = dolfin.Function(W)
+    u0 = Function(W)
     # arr = factor * numpy_mpi.gather_vector(u_int.vector())
     # numpy_mpi.assign_to_vector(u0.vector(), arr)
     u0.vector()[:] = factor * u_int.vector()
     V = dolfin.VectorFunctionSpace(mesh, "CG", 1)
-    U = dolfin.Function(V)
+    U = Function(V)
     U.vector()[:] = u0.vector()
     # numpy_mpi.assign_to_vector(U.vector(), arr)
 
@@ -112,6 +110,13 @@ def get_markers(mesh_type="lv"):
     return markers
 
 
+def get_geometric_dimension(mesh):
+    try:
+        return mesh.geometric_dimension()
+    except AttributeError:
+        return mesh.geometry().dim()
+
+
 def load_geometry_from_h5(
     h5name,
     h5group="",
@@ -175,7 +180,7 @@ def load_geometry_from_h5(
         # Get mesh functions
         for dim, attr in enumerate(["vfun", "efun", "ffun", "cfun"]):
 
-            if dim > mesh.geometric_dimension():
+            if dim > get_geometric_dimension(mesh):
                 setattr(geo, attr, None)
                 continue
 
@@ -309,7 +314,7 @@ def fill_coordinates_el(i, e_c_x, e_c_y, e_c_z, coord, foci):
 
 
 def calc_cross_products(e1, e2, VV):
-    e_crossed = dolfin.Function(VV)
+    e_crossed = Function(VV)
 
     e1_arr = e1.vector().get_local().reshape((-1, 3))
     e2_arr = e2.vector().get_local().reshape((-1, 3))
@@ -323,16 +328,16 @@ def calc_cross_products(e1, e2, VV):
 
 
 def make_unit_vector(V, VV, dofs_x, fill_coordinates, foc=None):
-    e_c_x = dolfin.Function(V)
-    e_c_y = dolfin.Function(V)
-    e_c_z = dolfin.Function(V)
+    e_c_x = Function(V)
+    e_c_y = Function(V)
+    e_c_z = Function(V)
 
     for i, coord in enumerate(dofs_x):
         fill_coordinates(i, e_c_x, e_c_y, e_c_z, coord, foc)
 
-    e = dolfin.Function(VV)
+    e = Function(VV)
 
-    fa = [dolfin.FunctionAssigner(VV.sub(i), V) for i in range(3)]
+    fa = [FunctionAssigner(VV.sub(i), V) for i in range(3)]
     for i, e_c_comp in enumerate([e_c_x, e_c_y, e_c_z]):
         fa[i].assign(e.split()[i], e_c_comp)
     return e
@@ -436,7 +441,7 @@ def get_long_field(mesh, mesh_type="biv"):
         # Mark the mesh with same markers on the LV and RV before
         # running the LDRB algorithm
         markers["ENDO_RV"] = markers["ENDO_LV"]
-        for facet in doflin.facets(mesh):
+        for facet in dolfin.facets(mesh):
             if ffun[facet] != 0:
                 mesh.domains().set_marker((facet.index(), markers[ffun[facet]]), 2)
 
@@ -446,7 +451,7 @@ def get_long_field(mesh, mesh_type="biv"):
     if mesh_type == "biv":
         # Put the correct markers
         markers = get_fiber_markers("biv")
-        for facet in doflin.facets(mesh):
+        for facet in dolfin.facets(mesh):
             if ffun[facet] != 0:
                 mesh.domains().set_marker((facet.index(), markers[ffun[facet]]), 2)
     return f0
@@ -485,86 +490,6 @@ def generate_fibers(mesh, fiber_params, ffun=None):
     return dolfin_ldrb(mesh, ffun=ffun, **angles)
 
 
-def generate_fibers_old(mesh, fiber_params):
-
-    try:
-        from fiberrules import dolfin_fiberrules
-    except ImportError as ex:
-        logger.error("Unable to generate fibers without fiberrules package")
-        logger.error("This package is protected by copyright")
-        raise ex
-
-    logger.info("\nGENERATING FIBERS ...")
-
-    fiber_space_name = fiber_params["fiber_space"]
-
-    assert (
-        len(fiber_space_name.split("_")) == 2
-    ), "expected fiber_space_name in 'FamilyName_Degree' format"
-
-    family, degree = fiber_space_name.split("_")
-
-    if DOLFIN_VERSION_MAJOR > 1.6:
-        el = dolfin.FiniteElement(
-            family=family,
-            cell=mesh.ufl_cell(),
-            degree=int(degree),
-            quad_scheme="default",
-        )
-        fiber_space = dolfin.FunctionSpace(mesh, el)
-    else:
-        fiber_space = dolfin.FunctionSpace(mesh, family, int(degree))
-
-    if family == "Quadrature":
-        dolfin.parameters["form_compiler"]["quadrature_degree"] = int(degree)
-        if DOLFIN_VERSION_MAJOR > 2016:
-            dolfin.parameters["form_compiler"]["representation"] = "quadrature"
-
-    # There are some strange shifting in the fiberrults angles
-    fiber_angle_epi = 90 - (-fiber_params["fiber_angle_epi"])
-    fiber_angle_endo = 90 - (fiber_params["fiber_angle_endo"])
-    sheet_angle_endo = fiber_params.to_dict().get("sheet_angle_endo", 0)
-    sheet_angle_epi = fiber_params.to_dict().get("sheet_angle_epi", 0)
-
-    microstructures = dolfin_fiberrules(
-        mesh,
-        fiber_space,
-        fiber_angle_epi,
-        fiber_angle_endo,
-        sheet_angle_epi,
-        sheet_angle_endo,
-    )
-
-    if DOLFIN_VERSION_MAJOR > 2016:
-        dolfin.parameters["form_compiler"]["representation"] = "uflacs"
-
-    microstructures[0].rename(
-        "fiber",
-        "epi{}_endo{}".format(
-            fiber_params["fiber_angle_epi"], fiber_params["fiber_angle_endo"]
-        ),
-    )
-    fields = [microstructures[0]]
-
-    if fiber_params["include_sheets"]:
-        microstructures[1].rename(
-            "sheet", "epi{}_endo{}".format(sheet_angle_epi, sheet_angle_endo)
-        )
-        microstructures[2].rename(
-            "cross_sheet",
-            "fepi{}_fendo{}_sepi{}_sendo{}".format(
-                fiber_params["fiber_angle_epi"],
-                fiber_params["fiber_angle_endo"],
-                sheet_angle_epi,
-                sheet_angle_endo,
-            ),
-        )
-        fields.append(microstructures[1])
-        fields.append(microstructures[2])
-
-    return fields
-
-
 def load_local_basis(h5file, lgroup, mesh, geo):
 
     if h5file.has_dataset(lgroup):
@@ -709,12 +634,10 @@ def save_geometry_to_h5(
 
         # Save mesh
         ggroup = "{}/geometry".format(h5group)
-
         mgroup = "{}/mesh".format(ggroup)
-
         h5file.write(mesh, mgroup)
 
-        for dim in range(mesh.geometric_dimension() + 1):
+        for dim in range(get_geometric_dimension(mesh) + 1):
 
             if meshfunctions is not None and dim in meshfunctions:
                 mf = meshfunctions[dim]
@@ -732,7 +655,6 @@ def save_geometry_to_h5(
             for name, (marker, dim) in markers.items():
 
                 for key_str in ["domain", "meshfunction"]:
-
                     dgroup = "{}/mesh/{}_{}".format(ggroup, key_str, dim)
 
                     if h5file.has_dataset(dgroup):
@@ -742,39 +664,12 @@ def save_geometry_to_h5(
         if local_basis is not None:
             # Save local basis functions
             lgroup = "{}/local basis functions".format(h5group)
-            names = []
-            for l in local_basis:
-                h5file.write(l, lgroup + "/{}".format(l.name()))
-                names.append(l.name())
-
-            elm = l.function_space().ufl_element()
-            family, degree = elm.family(), elm.degree()
-            lspace = "{}_{}".format(family, degree)
-            h5file.attributes(lgroup)["space"] = lspace
-            h5file.attributes(lgroup)["names"] = ":".join(names)
+            save_local_basis(h5file, lgroup, local_basis)
 
         if fields is not None:
             # Save fiber field
             fgroup = "{}/microstructure".format(h5group)
-            names = []
-            for field in fields:
-                try:
-                    label = (
-                        field.label() if field.label().rfind("a Function") == -1 else ""
-                    )
-                except AttributeError:
-                    label = field.name()
-                name = "_".join(filter(None, [str(field), label]))
-                fsubgroup = "{}/{}".format(fgroup, name)
-                h5file.write(field, fsubgroup)
-                h5file.attributes(fsubgroup)["name"] = field.name()
-                names.append(name)
-
-            elm = field.function_space().ufl_element()
-            family, degree = elm.family(), elm.degree()
-            fspace = "{}_{}".format(family, degree)
-            h5file.attributes(fgroup)["space"] = fspace
-            h5file.attributes(fgroup)["names"] = ":".join(names)
+            save_fields(h5file, fgroup, fields)
 
         if other_functions is not None:
             for k, fun in other_functions.items():
@@ -798,6 +693,61 @@ def save_geometry_to_h5(
     logger.info("Geometry saved to {}".format(h5name))
 
 
+def save_fields(h5file, fgroup, fields):
+    """Save mictrostructure to h5file
+
+    Parameters
+    ----------
+    h5file : dolfin.HDF5File
+        The file to write to
+    fgroup : str
+        The folder inside the file to write to
+    fields : list
+        List of dolfin functions to write
+    """
+    names = []
+    for field in fields:
+        try:
+            label = field.label() if field.label().rfind("a Function") == -1 else ""
+        except AttributeError:
+            label = field.name()
+        name = "_".join(filter(None, [str(field), label]))
+        fsubgroup = "{}/{}".format(fgroup, name)
+        h5file.write(field, fsubgroup)
+        h5file.attributes(fsubgroup)["name"] = field.name()
+        names.append(name)
+
+    elm = field.function_space().ufl_element()
+    family, degree = elm.family(), elm.degree()
+    fspace = "{}_{}".format(family, degree)
+    h5file.attributes(fgroup)["space"] = fspace
+    h5file.attributes(fgroup)["names"] = ":".join(names)
+
+
+def save_local_basis(h5file, lgroup, local_basis):
+    """Save local basis functions
+
+    Parameters
+    ----------
+    h5file : dolfin.HDF5File
+        The file to write to
+    lgroup : str
+        Folder inside file to store the local basis
+    local_basis : list
+        List of dolfin functions with local basis functions
+    """
+    names = []
+    for basis in local_basis:
+        h5file.write(basis, lgroup + "/{}".format(basis.name()))
+        names.append(basis.name())
+
+    elm = basis.function_space().ufl_element()
+    family, degree = elm.family(), elm.degree()
+    lspace = "{}_{}".format(family, degree)
+    h5file.attributes(lgroup)["space"] = lspace
+    h5file.attributes(lgroup)["names"] = ":".join(names)
+
+
 def mark_strain_regions(mesh, foc=None, nsectors=(6, 6, 4, 1), mark_mesh=True):
     """Mark the cells in the mesh.
 
@@ -805,7 +755,7 @@ def mark_strain_regions(mesh, foc=None, nsectors=(6, 6, 4, 1), mark_mesh=True):
     the  AHA 17-segment model, then nsector = [6,6,4,1],
     i.e 6 basal, 6 mid, 4 apical and one apex
 
-     """
+    """
 
     fun = dolfin.MeshFunction("size_t", mesh, 3)
     nlevels = len(nsectors)
@@ -880,7 +830,7 @@ def strain_region_number(T, regions):
     For a given point in prolate coordinates,
     return the region it belongs to.
 
-    :param regions: Array of all coordinates for the strain 
+    :param regions: Array of all coordinates for the strain
                     regions taken from the strain mesh.
     :type regions: :py:class:`numpy.array`
 
@@ -950,9 +900,9 @@ def get_sector(regions, theta):
 
 
 def estimate_focal_point(mesh):
-    """Copmute the focal point based on approximating the 
+    r"""Copmute the focal point based on approximating the
     endocardial surfaces as a ellipsoidal cap.
-    
+
     .. math::
 
            focal = \sqrt{ l^2 - s^2}
