@@ -1,51 +1,25 @@
 #!/usr/bin/env python
-import numpy as np
 import operator as op
+
 import dolfin
+import numpy as np
 
 try:
-    from dolfin_adjoint import Function, Constant
+    from dolfin_adjoint import Constant, Function
 
     has_dolfin_adjoint = True
 except ImportError:
-    from dolfin import Function, Constant
+    from dolfin import Constant, Function
 
     has_dolfin_adjoint = False
 
 
 from . import numpy_mpi
-from . import parameters, annotation
-from .mechanicsproblem import SolverDidNotConverge
 from .dolfin_utils import get_constant
-from .utils import make_logger, value_size
+from .mechanicsproblem import SolverDidNotConverge
+from .utils import Enlisted, delist, enlist, getLogger, value_size
 
-logger = make_logger(__name__, parameters["log_level"])
-
-
-class Enlisted(tuple):
-    pass
-
-
-def enlist(x, force_enlist=False):
-    if isinstance(x, Enlisted):
-        return x
-    elif isinstance(x, (list, tuple, np.ndarray)):
-        if force_enlist:
-            return Enlisted([x])
-        else:
-            return Enlisted(x)
-    else:
-        return Enlisted([x])
-
-
-def delist(x):
-    if isinstance(x, Enlisted):
-        if len(x) == 1:
-            return x[0]
-        else:
-            return x
-    else:
-        return x
+logger = getLogger(__name__)
 
 
 def copy(f, deepcopy=True, name="copied_function"):
@@ -69,16 +43,16 @@ def copy(f, deepcopy=True, name="copied_function"):
     elif isinstance(f, (float, int)):
         return f
     elif isinstance(f, Enlisted):
-        l = []
+        lst = []
         for fi in f:
-            l.append(copy(fi))
-        return enlist(l)
+            lst.append(copy(fi))
+        return enlist(lst)
 
     elif isinstance(f, (list, tuple)):
-        l = []
+        lst = []
         for fi in f:
-            l.append(copy(fi))
-        return tuple(l)
+            lst.append(copy(fi))
+        return tuple(lst)
     else:
         return f
 
@@ -281,6 +255,7 @@ def iterate(
     max_nr_crash=20,
     max_iters=40,
     initial_number_of_steps=5,
+    reinit_each_step=False,
 ):
 
     """
@@ -306,6 +281,8 @@ def iterate(
         Adapt / increase step size when sucessful iterations are achevied.
     old_states: list
         List of old controls to help speed in the continuation
+    reinit_each_step : bool
+        If True reinitialize form at each step.
     """
 
     with Iterator(
@@ -320,6 +297,7 @@ def iterate(
         max_nr_crash=max_nr_crash,
         max_iters=max_iters,
         initial_number_of_steps=initial_number_of_steps,
+        reinit_each_step=reinit_each_step,
     ) as iterator:
         res = iterator.solve()
 
@@ -336,8 +314,6 @@ class Iterator(object):
     def __init__(
         self, problem, control, target, old_states=None, old_controls=None, **params
     ):
-
-        logger.setLevel(parameters["log_level"])
         self.parameters = Iterator.default_parameters()
         self.parameters.update(params)
 
@@ -374,6 +350,7 @@ class Iterator(object):
             max_nr_crash=20,
             max_iters=40,
             initial_number_of_steps=5,
+            reinit_each_step=False,
         )
 
     @property
@@ -402,6 +379,9 @@ class Iterator(object):
 
         self.ncrashes = 0
         self.niters = 0
+        logger.info("Iterating....")
+        logger.info(print_control(self.control, "Current control: "))
+        logger.info(print_control(self.target, "Target: "))
         while not self.target_reached():
 
             self.niters += 1
@@ -429,7 +409,7 @@ class Iterator(object):
             if self.parameters["continuation"]:
                 self.continuation_step()
 
-            logger.info("Try new control")
+            logger.debug("Try new control")
             self.print_control()
 
             try:
@@ -437,8 +417,8 @@ class Iterator(object):
 
             except SolverDidNotConverge as ex:
                 logger.debug(ex)
-                logger.info("\nNOT CONVERGING")
-                logger.info("Reduce control step")
+                logger.debug("\nNOT CONVERGING")
+                logger.debug("Reduce control step")
                 self.ncrashes += 1
                 self.assign_control(prev_control)
                 # Assign old state
@@ -449,8 +429,8 @@ class Iterator(object):
                 self.change_step_size(0.5)
 
             else:
-                ncrashes = 0
-                logger.info("\nSUCCESFULL STEP:")
+                self.ncrashes = 0
+                logger.debug("\nSUCCESFULL STEP:")
 
                 if not self.target_reached():
                     if (
@@ -462,7 +442,7 @@ class Iterator(object):
                             np2str(self.step)
                         )
                         # print_control(enlist(self.step), msg)
-                        logger.info(msg)
+                        logger.debug(msg)
 
                 self.control_values.append(
                     delist(copy(self.control, deepcopy=True, name="Previous control"))
@@ -483,7 +463,7 @@ class Iterator(object):
     def print_control(self):
         msg = "Current control: "
         msg = print_control(self.control, msg)
-        logger.info(msg)
+        logger.debug(msg)
 
     def continuation_step(self):
 
@@ -522,6 +502,9 @@ class Iterator(object):
                 c_arr = c
                 c.assign(Constant(constant2float(c) + s))
 
+        if self.parameters["reinit_each_step"]:
+            self.problem._init_forms()
+
     def assign_control(self, new_control):
         """
         Assign a new value to the control
@@ -533,10 +516,10 @@ class Iterator(object):
                 c.assign(Constant(n))
 
     def change_step_for_final_iteration(self, prev_control):
-        """Change step size so that target is 
+        """Change step size so that target is
         reached in the next iteration
         """
-        logger.info("Change step size for final iteration")
+        logger.debug("Change step size for final iteration")
 
         target = delist(self.target)
         prev_control = delist(prev_control)
@@ -588,7 +571,7 @@ class Iterator(object):
         for t in self.target[1:]:
             if value_size(t0) > 1 or value_size(t) > 1:
                 raise (ValueError(msg))
-        logger.info("Target: {}".format([constant2float(t) for t in self.target]))
+        logger.debug("Target: {}".format([constant2float(t) for t in self.target]))
 
     def _check_control(self, control):
 
@@ -602,17 +585,15 @@ class Iterator(object):
             assert isinstance(c, self._control_types), msg
 
         self.control = control
-        logger.info("Control: {}".format([constant2float(c) for c in self.control]))
+        logger.debug("Control: {}".format([constant2float(c) for c in self.control]))
 
     @property
     def ncontrols(self):
-        """Number of controls
-        """
+        """Number of controls"""
         return len(self.control)
 
     def target_reached(self):
-        """Check if control and target are the same
-        """
+        """Check if control and target are the same"""
         diff = get_diff(self.control, self.target)
 
         if isinstance(diff, dolfin.GenericVector):
@@ -625,9 +606,9 @@ class Iterator(object):
 
         reached = max_diff < 1e-6
         if reached:
-            logger.info("Check target reached: YES!")
+            logger.debug("Check target reached: YES!")
         else:
-            logger.info("Check target reached: NO")
-            logger.info("Maximum difference: {:.3e}".format(max_diff))
+            logger.debug("Check target reached: NO")
+            logger.debug("Maximum difference: {:.3e}".format(max_diff))
 
         return reached
