@@ -6,23 +6,11 @@ import dolfin
 import ufl
 
 try:
-    from dolfin_adjoint import (
-        Function,
-        Constant,
-        FunctionAssigner,
-        NonlinearVariationalSolver,
-        NonlinearVariationalProblem,
-    )
+    from dolfin_adjoint import Constant, Function, FunctionAssigner
 
     has_dolfin_adjoint = True
 except ImportError:
-    from dolfin import (
-        Function,
-        Constant,
-        FunctionAssigner,
-        NonlinearVariationalSolver,
-        NonlinearVariationalProblem,
-    )
+    from dolfin import Constant, Function, FunctionAssigner
 
     has_dolfin_adjoint = False
 
@@ -33,12 +21,13 @@ except ImportError:
     from dolfin import DirichletBC
 
 from . import kinematics
-from . import parameters
-from .utils import set_default_none, make_logger, get_lv_marker
-from .geometry import HeartGeometry
 from .dolfin_utils import list_sum
+from .geometry import Geometry, HeartGeometry
+from .material import Material
+from .solver import NonlinearProblem, NonlinearSolver
+from .utils import get_lv_marker, getLogger, set_default_none
 
-logger = make_logger(__name__, parameters["log_level"])
+logger = getLogger(__name__)
 
 BoundaryConditions = namedtuple(
     "BoundaryConditions", ["dirichlet", "neumann", "robin", "body_force"]
@@ -47,21 +36,20 @@ set_default_none(BoundaryConditions, ())
 
 NeumannBC = namedtuple("NeumannBC", ["traction", "marker", "name"])
 # Name is optional
-NeumannBC.__new__.__defaults__ = ("",)
+NeumannBC.__new__.__defaults__ = ("",)  # type: ignore
 RobinBC = namedtuple("RobinBC", ["value", "marker"])
 
 
 def dirichlet_fix_base(W, ffun, marker):
-    """Fix the basal plane.
-    """
+    """Fix the basal plane."""
     V = W if W.sub(0).num_sub_spaces() == 0 else W.sub(0)
-    bc = DirichletBC(V, dolfin.Constant((0, 0, 0)), ffun, marker)
+    bc = DirichletBC(V, Constant((0, 0, 0)), ffun, marker)
     return bc
 
 
 def dirichlet_fix_base_directional(W, ffun, marker, direction=0):
     V = W if W.sub(0).num_sub_spaces() == 0 else W.sub(0)
-    bc = DirichletBC(V.sub(direction), dolfin.Constant(0.0), ffun, marker)
+    bc = DirichletBC(V.sub(direction), Constant(0.0), ffun, marker)
     return bc
 
 
@@ -97,8 +85,7 @@ def cardiac_boundary_conditions(
 
         robin_bc = [
             RobinBC(
-                value=dolfin.Constant(pericardium_spring),
-                marker=geometry.markers["EPI"][0],
+                value=Constant(pericardium_spring), marker=geometry.markers["EPI"][0]
             )
         ]
 
@@ -108,9 +95,7 @@ def cardiac_boundary_conditions(
     # Apply a linear sprint robin type BC to limit motion
     if base_spring > 0.0:
         robin_bc += [
-            RobinBC(
-                value=dolfin.Constant(base_spring), marker=geometry.markers["BASE"][0]
-            )
+            RobinBC(value=Constant(base_spring), marker=geometry.markers["BASE"][0])
         ]
 
     # Dirichlet BC
@@ -153,7 +138,12 @@ class MechanicsProblem(object):
     """
 
     def __init__(
-        self, geometry, material, bcs=None, bcs_parameters=None, solver_parameters=None
+        self,
+        geometry: Geometry,
+        material: Material,
+        bcs=None,
+        bcs_parameters=None,
+        solver_parameters=None,
     ):
 
         logger.debug("Initialize mechanics problem")
@@ -185,12 +175,13 @@ class MechanicsProblem(object):
         for attr in ("f0", "s0", "n0"):
             setattr(self.material, attr, getattr(self.geometry, attr))
 
-        self._init_spaces()
-        self._init_forms()
-        self.solver_parameters = MechanicsProblem.defaul_solver_parameters()
+        self.solver_parameters = NonlinearSolver.default_solver_parameters()
         if solver_parameters is not None:
             self.solver_parameters.update(**solver_parameters)
 
+        self._init_spaces()
+        self._init_forms()
+
     @staticmethod
     def default_bcs_parameters():
         return dict(pericardium_spring=0.0, base_spring=0.0, base_bc="fixed")
@@ -230,9 +221,23 @@ class MechanicsProblem(object):
             internal_energy * dx, self.state, self.state_test
         )
 
-        self._virtual_work += self._external_work(u, v)
+        external_work = self._external_work(u, v)
+        if external_work is not None:
+            self._virtual_work += external_work
 
         self._set_dirichlet_bc()
+        self._jacobian = dolfin.derivative(
+            self._virtual_work, self.state, dolfin.TrialFunction(self.state_space)
+        )
+        self._init_solver()
+
+    def _init_solver(self):
+        self._problem = NonlinearProblem(
+            J=self._jacobian, F=self._virtual_work, bcs=self._dirichlet_bc
+        )
+        self.solver = NonlinearSolver(
+            self._problem, self.state, parameters=self.solver_parameters
+        )
 
     def _set_dirichlet_bc(self):
         # DirichletBC
@@ -282,12 +287,11 @@ class MechanicsProblem(object):
 
         if len(external_work) > 0:
             return list_sum(external_work)
-        else:
-            return dolfin.Constant(0.0)
+
+        return None
 
     def reinit(self, state, annotate=False):
-        """Reinitialze state
-        """
+        """Reinitialze state"""
 
         if has_dolfin_adjoint:
             try:
@@ -301,8 +305,8 @@ class MechanicsProblem(object):
         self._init_forms()
 
     @staticmethod
-    def defaul_solver_parameters():
-        return dolfin.NonlinearVariationalSolver.default_parameters()
+    def default_solver_parameters():
+        return NonlinearSolver.default_solver_parameters()
 
     def solve(self):
         r"""
@@ -314,10 +318,6 @@ class MechanicsProblem(object):
 
         """
 
-        self._jacobian = dolfin.derivative(
-            self._virtual_work, self.state, dolfin.TrialFunction(self.state_space)
-        )
-
         logger.debug("Solving variational problem")
         # Get old state in case of non-convergence
         if has_dolfin_adjoint:
@@ -330,16 +330,11 @@ class MechanicsProblem(object):
 
         else:
             old_state = self.state.copy(deepcopy=True)
-        problem = NonlinearVariationalProblem(
-            self._virtual_work, self.state, self._dirichlet_bc, self._jacobian
-        )
-
-        solver = NonlinearVariationalSolver(problem)
-        solver.parameters.update(self.solver_parameters)
 
         try:
             logger.debug("Try to solve")
-            nliter, nlconv = solver.solve()
+            nliter, nlconv = self.solver.solve()
+
             if not nlconv:
                 logger.debug("Failed")
                 raise SolverDidNotConverge("Solver did not converge...")
@@ -370,3 +365,23 @@ class MechanicsProblem(object):
             fa.assign(u, self.state.split()[0])
 
         return u
+
+    def SecondPiolaStress(self):
+        u, p = self.state.split(deepcopy=True)
+        F = kinematics.DeformationGradient(u)
+        return self.material.SecondPiolaStress(F, p)
+
+    def FirstPiolaStress(self):
+        u, p = self.state.split(deepcopy=True)
+        F = kinematics.DeformationGradient(u)
+        return self.material.FirstPiolaStress(F, p)
+
+    def ChachyStress(self):
+        u, p = self.state.split(deepcopy=True)
+        F = kinematics.DeformationGradient(u)
+        return self.material.CauchyStress(F, p)
+
+    def GreenLagrangeStrain(self):
+        u, p = self.state.split(deepcopy=True)
+        F = kinematics.DeformationGradient(u)
+        return kinematics.GreenLagrangeStrain(F)
